"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FormikCheckboxGroup = FormikCheckboxGroup;
exports.FormikCheckboxGroupField = void 0;
var _react = require("react");
var _formik = require("formik");
var _practicalReactComponentsCore = require("practical-react-components-core");
var _styledComponents = _interopRequireWildcard(require("styled-components"));
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var CheckboxContainer = _styledComponents.default.div.withConfig({
  displayName: "FormikCheckboxGroup__CheckboxContainer",
  componentId: "sc-y96del-0"
})(["", ""], _ref => {
  var {
    halfOptionLength
  } = _ref;
  return (0, _styledComponents.css)(["display:grid;grid-template-columns:auto auto;grid-template-rows:repeat(", ",auto);grid-row-gap:", ";grid-auto-flow:column;"], halfOptionLength, _practicalReactComponentsCore.spacing.medium);
});

/**
 * Component that creates a group of checkboxes from the options prop.
 * The checkboxes is ordered in two columns, the first half of options in the first checkbox column,
 * last half of options in the right column.
 *
 * Eg:
 *
 * Options: [option1, option2, option3, option4]
 *
 * `[X] option1 [ ] option3`
 *
 * `[ ] option2 [X] option4`
 */
function FormikCheckboxGroup(_ref2) {
  var {
    name,
    validate,
    options
  } = _ref2;
  var [{
    value
  },, {
    setValue
  }] = (0, _formik.useField)({
    name,
    validate
  });

  /**
   * Number used to stack the first half of the options in left checkbox column
   * and the last half in the right column.
   */
  var halfOptionLength = (0, _react.useMemo)(() => Math.ceil(options.length / 2), [options]);
  var onChanges = (0, _react.useMemo)(() => options.map(option => () => {
    if (!value.includes(option.value)) {
      setValue([...value, option.value]);
    } else {
      setValue(value.filter(v => v !== option.value));
    }
  }), [options, value, setValue]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(CheckboxContainer, {
    halfOptionLength: halfOptionLength,
    children: options.map((option, i) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_practicalReactComponentsCore.Checkbox, {
      name: name,
      label: option.label,
      value: option.value,
      checked: value.includes(option.value),
      onChange: onChanges[i]
    }, option.value))
  });
}
var FormikCheckboxGroupField = props => (0, _practicalReactComponentsCore.withField)(FormikCheckboxGroup)(props);
exports.FormikCheckboxGroupField = FormikCheckboxGroupField;